<!-- This guide is heavily inspired by GitLab's own contributing guide for its design team. Kudos to them! -->

Thank you for your interest in contributing to PeerTube's design. Our team is building a software, but we don't forget its core concept still is to interact with people. Here's how you can help them better get along.

---

# Contribution guidelines

<!-- Table of contents generated with DocToc: https://github.com/thlorenz/doctoc -->
<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->


- [Onboarding :strawberry:](#onboarding-strawberry)
  - [Open Source Design](#open-source-design)
  - [Suggested workflow](#suggested-workflow)
  - [Suggested Software](#suggested-software)
    - [Sketch](#sketch)
    - [Adobe XD](#adobe-xd)
- [Organization](#organization)
  - [Naming](#naming)
  - [Files and folders](#files-and-folders)
  - [Pages and artboards](#pages-and-artboards)
- [Git](#git)
  - [Commits](#commits)
  - [Large Files Storage](#large-files-storage)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

## Onboarding :strawberry:

Everyone can contribute to PeerTube's design. Anyone who influences what the design becomes is the designer. This includes developers, PMs, even corporate legal. All are the designers.<sup>[1](https://twitter.com/jmspool/status/836955987860914176)</sup>

The project is still low on resources and no dedicated design team has been established, nor a dedicated design repository − yet. We are trying to get you to speed nonetheless, and make communication between design-literate and code-literate people as easy as possible.

### Open Source Design

We care about [Open Source Design](http://opensourcedesign.net/goals/), and Open Design in general. Making the design process open is an important thing for us, as interfaces too can greatly impact the resulting software, in bad or good.

It implies putting your files in the open and iterating to modify it with others until consensus. More specifically, it means dividing a given design problem in manageable parts, and track them [in public](issue-link) for us to help :smiley:.

You might want to read some more here, although these are just hints:
- http://opendesignkit.org/process/

### Suggested workflow

1. See what you think about is being tackled by others on the [issue tracker](issue-link)
1. Think of using pen & paper. High-end software isn't the goal. Design is.
<!-- 1. [Fork this project][fork-link] to your personal namespace. Or don't: it's just a suggested skeleton project to help you get started and structure your proposal. -->
1. Create a repository from your fork.
   - Be very descriptive of the changes you've made. The reviewer will have to manually merge them, which means they have to be aware of even the smallest changes as they could be easy to miss.
1. Create an issue on [PeerTube's repository](issue-link).
   - Please use this [issue template](https://gist.github.com/rigelk/3350ba0670a9b7fab9a3df08a1de6367).
   - Mention _only one_ of the maintainers to review.
   - The issue will ultimately be edited/closed as the changes need to be converted to integration/code tasks.
1. High-five yourself and go brew some :coffee: while you wait for the review(s). Thanks! :raised_hands:

### Suggested Software

Again, think of using [paper & pencil first](http://alistapart.com/article/paperprototyping).

We recommend first and foremost open source software such as [Inkscape](https://inkscape.org/en/) or [Pencil](http://pencil.evolus.vn/) (a [complete list](http://opensourcedesign.net/resources/#design-tools)), but at the same time we know most of them are behind popular software for web design workflows. You can use any design software that's available to you. Just make sure to include editable exports (SVG, PDF, EPS) along with your source files.

#### Sketch

Some pointers to open files from [Sketch](https://www.sketchapp.com/):

- [Sketch-react](https://zjuasmn.github.io/sketch-react/): Web app that supports multiple pages. Admits uploading files and referencing by URL.
- [Sketch Web Viewer](https://animaapp.github.io/sketch-web-viewer/): Web app that supports uploaded files.
- [Figma](https://www.figma.com/): Powerful tool for UX and UI design. It has a web interface as well as desktop apps (internet connection required). It’s free for individuals.
- [Photopea](https://www.photopea.com/): Free web editor for Sketch, Photoshop and Gimp files. The only editable export format is PSD, which may not be fully compatible for Sketch import.

We recommend installing the following Sketch plugins to improve your design
workflow. Don’t forget to read the documentation of each plugin to use them
properly. If you’d like to recommend a plugin, please [create an issue](https://PeerTube.com/PeerTube-org/PeerTube-design/issues/new).

- [Relabel Button](https://github.com/kenmoore/sketch-relabel-button): Prompts for a button’s new label, applies the text, resizes the button background, and repositions any other interior elements while maintaining the existing padding. It’s essentially awesome voodoo magic.
- [Git Plugin](https://mathieudutour.github.io/git-sketch-plugin/): A Git client built right into Sketch. The plugin really improves the review process by exporting an image for every part of the design.

#### Adobe XD

Some pointers to open files from [Adobe XD](https://www.adobe.com/fr/products/xd.html).

## Organization

### Naming

Follow these guidelines when naming files and folders, as well as
layers and styles in your source files:
- Adhere to [BEM naming convention](http://getbem.com/naming/): `block-name__element-name--modifier-name`
- Readability above truncation: `background` instead of `bg`
- `lowercase` everywhere
- Separate words with dashes, `no-spaces`

### Files and folders

```
- [group-label]/ (e.g. platform)
  - [subject-labels]/ (e.g. settings)
    - projecthandle#issueID-title.sketch (e.g. ce#1337-awesome-design.sketch)
    - [projecthandle#issue-ID-title]/
      - projecthandle#issueID-title--state-one.sketch
      - projecthandle#issueID-title--state-two.sketch
        - assets/
          - asset.svg
```

In any case, if the project becomes too complex (i.e. for a complete redesign proposal, please refer to the [design proposals section](#major-design-proposals).

### Pages and artboards

In terms of organization method, use the one that best suits you. However, if
you think the file is becoming too complex, consider organizing it with different
pages and/or artboards. For example, pages can be different issues and artboards can be
different states. Remember to follow the [naming guidelines](#naming).

See the [Files and folders](#files-and-folders) section for naming and
organizing Sketch files.

## Git

Git is hard: screwing up is easy, and figuring out how to fix your mistakes is
sometimes almost impossible. Yet that's one of the best tool to deal with heterogeneous groups of people (you!) coming from all over the world. It brings structure to chaos.

Begin by [learning git interactively](https://try.github.io/), or with [a video](https://git-scm.com/videos). There is also that [dead simple site explaining it](http://rogerdudler.github.io/git-guide/). Or the verbose [official documentation of Git](https://git-scm.com/doc). Tons of ways, really.

Here are some more links and tips to help you
along! :v:

- Revert your changes to a file and make it as if you never touched it: `git checkout FILEPATH/FILE`
- If you already did a commit but want to uncommit those changes (before pushing): `git reset HEAD^`
- If you feel you screwed up some more, there is the infamous [Dang it git!](http://dangitgit.com/) site, and don't be afraid to ask us.

Don't forget the section about `git-lfs`. Large files as graphics sources slow down Git, and need that special plugin to be dealt with.

### Commits

Commiting changes is the action to bundle the changes you've made in a set that can be shared with others. Of course some rules apply to that step, and good practices too that can help you do more with commits:

- Write a [good commit message](https://chris.beams.io/posts/git-commit/)
- Install the [Git hook][git-hooks] that automates adding issue/merge request IDs to commit messages:
   - At the root of the repository, run `ln -s ../../hooks/prepare-commit-msg .git/hooks/prepare-commit-msg`. This will keep your local Git hook up-to-date.
   - Once installed, every time you commit, the hook will add the issues and merge requests IDs found on the staged files (and their folders) to the commit message body (e.g. `PeerTube-webui#1337` or `ux-research!1337`).
   - It only works if you follow the naming pattern described in the [Files and folders](#files-and-folders) section.
   - These references automatically create a commit note in the corresponding issue/merge request, making it easy for other people to contribute and fork the design (especially important if someone is out-of-office).

### Large Files Storage

Sketch files or PSDs can be huge, and well above what Git is made for (files way under 100MB). But fear not, Git Large File Storage (LFS) replaces large files such as audio samples, videos, datasets, and graphics with text pointers inside Git, while storing the file contents on a remote server.

However, you need to set it up. A tutorial can be found on [GitHub's site](https://git-lfs.github.com/).

[fork-link]: https://github.com/Chocobozzz/PeerTube/#fork-destination-box
[issue-link]: https://github.com/Chocobozzz/PeerTube/labels/ui
[framer]: https://framer.com
[git-hooks]: https://git-scm.com/docs/githooks
